@@ -190,3 +190,35 @@ create_fold_and_fold_column_map <- function(data, fold_info_cols){
     )) %>%
     dplyr::distinct()
 }
+
+# Extracts the major and minor version numbers.
+check_R_version <- function(){
+  major <- as.integer(R.Version()$major)
+  minor <- as.numeric(strsplit(R.Version()$minor, ".", fixed = TRUE)[[1]][[1]])
+  list("major"=major, "minor"=minor)
+}
+
+# Skips testthat test, if the R version is below 3.6.0
+# WHY? Due to the change in the random sampling generator
+# tests fail on R versions below 3.6.0.
+# It is possible to fix this by using the old generator for
+# unit tests, but that would take a long time to convert,
+# and most likely the code works the same on v3.5
+skip_test_if_old_R_version <- function(min_R_version = "3.6"){
+  if(check_R_version()[["minor"]] < strsplit(min_R_version, ".", fixed = TRUE)[[1]][[2]]){
+    testthat::skip(message = paste0("Skipping test as R version is < ", min_R_version, "."))
+  }
+}
+
+# Wrapper for setting seed with the sample generator for R versions <3.6
+# Used for unittests
+# Partly contributed by R. Mark Sharp
+set_seed_for_R_compatibility <- function(seed = 1) {
+  version <- check_R_version()
+  if (version[["minor"]] >= 6) {
+    args <- list(seed, sample.kind = "Rounding")
+  } else {
+    args <- list(seed)
+  }
+  suppressWarnings(do.call(set.seed, args))
+}
